@@ -1,40 +1,19 @@
 # pylint: disable=no-self-argument,no-self-use
 
-import re
+import sys
 
 # Disabling pylint no-name-in-module because this is the documented way to
 # import `BaseModel` and it's not broken, so let's keep it.
-from pydantic import (  # pylint: disable=no-name-in-module
-    BaseModel as _BaseModel,
-    Extra,
-    Field,
-    validator,
-)
-from typing import Any, Dict, List, Literal, Optional, Union
+from pydantic import Field, validator  # pylint: disable=no-name-in-module
+from typing import Any, Dict, List, Optional, Union
+
+from .base import BaseModel
 
 
-under_pat = re.compile(r"_([a-z])")
-
-
-def underscore_to_camel(name):
-    ret = under_pat.sub(lambda x: x.group(1).upper(), name)
-    return ret
-
-
-class BaseModel(_BaseModel):
-    class Config:
-        """Config override for all models.
-
-        This override is mainly so everything can go from snake to camel-case.
-        """
-
-        alias_generator = underscore_to_camel
-        allow_population_by_field_name = True
-
-        # Allow extra fields even if it is not defined. This will allow models
-        # to be more flexible if features are added in the Anvil API, but
-        # explicit support hasn't been added yet to this library.
-        extra = Extra.allow
+if sys.version_info >= (3, 8):
+    from typing import Literal  # pylint: disable=no-name-in-module
+else:
+    from typing_extensions import Literal
 
 
 class EmbeddedLogo(BaseModel):
@@ -158,6 +137,7 @@ class CreateEtchPacketPayload(BaseModel):
     signature_email_body: Optional[str] = None
     is_draft: Optional[bool] = False
     is_test: Optional[bool] = True
+    merge_pdfs: Optional[bool] = Field(None, alias="mergePDFs")
     data: Optional[CreateEtchFilePayload] = None
     signature_page_options: Optional[Dict[Any, Any]] = None
     webhook_url: Optional[str] = Field(None, alias="webhookURL")
